@@ -210,7 +210,7 @@ setMethod(".addhandlerkeystroke",
           function(obj,toolkit, handler=NULL, action=NULL,...) {
             widget <- getWidget(obj)
             ID <-
-              gSignalConnect(widget,signal = "key-press-event",
+              gSignalConnect(widget,signal = "key-release-event",
                              f = function(d,widget,event,...) {
                                h <- list(obj=d$obj,action=d$action)
                                key <- event$GetString()
